import cv2
from cv2 import aruco


def findArucoMarkers(img, markerSize, totalMarkers=250, draw=True):
    gray = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY)
    key = getattr(aruco, f'DICT_{markerSize}X{markerSize}_{totalMarkers}')
    arucoDict = aruco.Dictionary_get(key)
    arucoParam = aruco.DetectorParameters_create()
    bboxs, ids, rejected = aruco.detectMarkers(gray, arucoDict, parameters=arucoParam)

    if draw:
        aruco.drawDetectedMarkers(img, bboxs)
    return bboxs[0][0]


img = cv2.imread("2.png")

print(findArucoMarkers(img,6))


from io import open
from setuptools import setup


setup(
    name='arucodetect',
    version='1.1',
    author='myortf_inside',
    author_email='faridgarifullin66@gmail.com',

    packages=['arucodetect'],
    install_requires = ['opencv-python']
)